@@ -67,6 +67,8 @@ cache = dogpile.cache.make_region().configure(
     **app.config.get('DATAGREPPER_CACHE_KWARGS', {})
 )
 
+import datagrepper.widgets
+
 
 @app.before_request
 def check_auth():
@@ -165,7 +167,7 @@ def preload_docs(endpoint):
     api_docs = markupsafe.Markup(api_docs)
     return api_docs
 
-htmldocs = dict.fromkeys(['index', 'reference'])
+htmldocs = dict.fromkeys(['index', 'reference', 'widget'])
 for key in htmldocs:
     htmldocs[key] = preload_docs(key)
 
@@ -208,6 +210,12 @@ def reference():
     return flask.render_template('index.html', docs=load_docs(flask.request))
 
 
+@app.route('/widget/')
+@app.route('/widget')
+def widget():
+    return flask.render_template('index.html', docs=load_docs(flask.request))
+
+
 # Instant requests
 @app.route('/raw/')
 @app.route('/raw')
@@ -225,6 +233,13 @@ def raw():
     packages = flask.request.args.getlist('package')
     categories = flask.request.args.getlist('category')
     topics = flask.request.args.getlist('topic')
+    contains = flask.request.args.getlist('contains')
+
+    # Still more filters.. negations of the previous ones.
+    not_users = flask.request.args.getlist('not_user')
+    not_packages = flask.request.args.getlist('not_package')
+    not_categories = flask.request.args.getlist('not_category')
+    not_topics = flask.request.args.getlist('not_topic')
 
     # Paging arguments
     page = int(flask.request.args.get('page', 1))
@@ -247,6 +262,11 @@ def raw():
         packages=packages,
         categories=categories,
         topics=topics,
+        contains=contains,
+        not_users=not_users,
+        not_packages=not_packages,
+        not_categories=not_categories,
+        not_topics=not_topics,
         page=page,
         rows_per_page=rows_per_page,
         order=order,
@@ -282,6 +302,11 @@ def raw():
             packages=packages,
             categories=categories,
             topics=topics,
+            contains=contains,
+            not_users=not_users,
+            not_packages=not_packages,
+            not_categories=not_categories,
+            not_topics=not_topics,
         )
 
         # Convert our messages from sqlalchemy objects to json-like dicts
